<?php
/**
 * WHMCS WayForPay Payment Gateway Module
 *
 *
 * @copyright Copyright (c) ITos 2016
 * http://itos.dp.ua
 */

require_once __DIR__ . '/../../../init.php';
require_once __DIR__ . '/../../../includes/gatewayfunctions.php';
require_once __DIR__ . '/../../../includes/invoicefunctions.php';

$gateway_module_name = basename(__FILE__, '.php');

$gateway_params = getGatewayVariables($gateway_module_name);

if (!$gateway_params['type']) {
    die('Module Not Activated');
}

$json = file_get_contents("php://input");
$request = json_decode($json);

$invoice_id = explode('/', $request->orderReference);
$invoice_id = $invoice_id[0];
$transaction_id = $request->orderReference;
$payment_amount = $request->amount;
$payment_fee = $request->fee;

$secretKey = $gateway_params['secretKey'];

$sign_string = "$request->merchantAccount;$request->orderReference;$request->amount;$request->currency;$request->authCode;$request->cardPan;$request->transactionStatus;$request->reasonCode";
$sign = hash_hmac('md5', $sign_string, $secretKey);
$transaction_status = 'Hash Verification Failure';
$success = false;

if ($request->merchantSignature == $sign)
{
	$success = true;
	$response_status = 'accept';
}
else
	$response_status = 'Hash Verification Failure';

$transaction_status = $success ? 'Success' : 'Failure';

if ($request->transactionStatus != 'Approved' && $request->reasonCode != 1100)
{
	$success = false;
	$transaction_status = $request->reason;
}

$invoice_id = checkCbInvoiceID($invoice_id, $gateway_params['name']);

checkCbTransID($transaction_id);

logTransaction($gateway_params['name'], (array)$request, $transaction_status);

if ($success) {
	addInvoicePayment(
        $invoice_id,
        $transaction_id,
        $payment_amount,
        $payment_fee,
        $gateway_module_name
    );
}

$response = [
	'orderReference' => $request->orderReference,
	'status' => $response_status,
	'time' => time()
];
$response['signature'] = '';
$response['signature'] .= $response['orderReference'] . ';';
$response['signature'] .= $response['status'] . ';';
$response['signature'] .= $response['time'];
$response['signature'] = hash_hmac('md5', $response['signature'], $secretKey);

$response = json_encode($response);

header("Content-Type: application/json; charset=UTF-8");

echo $response;
